@@ -135,6 +135,7 @@ void show_conn_flags(unsigned int f)
 	SHOW_FLAG(f, CO_FL_ADDR_TO_SET);
 	SHOW_FLAG(f, CO_FL_ADDR_FROM_SET);
 	SHOW_FLAG(f, CO_FL_WAIT_ROOM);
+	SHOW_FLAG(f, CO_FL_WILL_UPDATE);
 	SHOW_FLAG(f, CO_FL_XPRT_READY);
 	SHOW_FLAG(f, CO_FL_CTRL_READY);
 	SHOW_FLAG(f, CO_FL_CURR_WR_ENA);
@@ -149,6 +150,28 @@ void show_conn_flags(unsigned int f)
 	}
 	putchar('\n');
 }
+void show_cs_flags(unsigned int f)
+{
+	printf("cs->flags = ");
+	if (!f) {
+		printf("0\n");
+		return;
+	}
+	SHOW_FLAG(f, CS_FL_EOS);
+	SHOW_FLAG(f, CS_FL_RCV_MORE);
+	SHOW_FLAG(f, CS_FL_ERROR);
+	SHOW_FLAG(f, CS_FL_SHWS);
+	SHOW_FLAG(f, CS_FL_SHWN);
+	SHOW_FLAG(f, CS_FL_SHRR);
+	SHOW_FLAG(f, CS_FL_SHRD);
+	SHOW_FLAG(f, CS_FL_DATA_WR_ENA);
+	SHOW_FLAG(f, CS_FL_DATA_RD_ENA);
+
+	if (f) {
+		printf("EXTRA(0x%08x)", f);
+	}
+	putchar('\n');
+}
 
 void show_si_et(unsigned int f)
 {
@@ -369,6 +392,7 @@ int main(int argc, char **argv)
 	show_strm_flags(flags);
 	show_si_et(flags);
 	show_si_flags(flags);
+	show_cs_flags(flags);
 	show_conn_flags(flags);
 	show_chn_flags(flags);
 	show_chn_ana(flags);
